==> ejc-salary-api-3.0.0-20240920.092035-6-sources.jar: com/ejianc/business/salary/vo/RosterSocialSecurityVO.java <==
package com.ejianc.business.salary.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 人员花名册-社保
 * 
 * @author generator
 * 
 */
public class RosterSocialSecurityVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private BigDecimal paymentBase; // 缴费基数
    private Date startTime; // 社保执行时间
    private Date endTime; // 社保结束时间
    private BigDecimal personAnnuityMoney; // 个人养老金
    private BigDecimal companyAnnuityMoney; // 公司养老金
    private BigDecimal personMedicalMoney; // 个人医疗金额
    private BigDecimal companyMedicalMoney; // 公司医疗金额
    private BigDecimal personUnemploymentMoney; // 个人失业金额
    private BigDecimal companyUnemploymentMoney; // 公司失业金额
    private BigDecimal companyChildbirthMoney; // 公司生育金额
    private BigDecimal companyInjuryMoney; // 公司工伤金额
    private String changeReason; // 变更原因
    private String dataState; // 状态
    private String employeeCode; // 员工编码
    private String idCard; // 身份证号
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public BigDecimal getPaymentBase() {
        return paymentBase;
    }

    public void setPaymentBase(BigDecimal paymentBase) {
        this.paymentBase = paymentBase;
    }
    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
    public BigDecimal getPersonAnnuityMoney() {
        return personAnnuityMoney;
    }

    public void setPersonAnnuityMoney(BigDecimal personAnnuityMoney) {
        this.personAnnuityMoney = personAnnuityMoney;
    }
    public BigDecimal getCompanyAnnuityMoney() {
        return companyAnnuityMoney;
    }

    public void setCompanyAnnuityMoney(BigDecimal companyAnnuityMoney) {
        this.companyAnnuityMoney = companyAnnuityMoney;
    }
    public BigDecimal getPersonMedicalMoney() {
        return personMedicalMoney;
    }

    public void setPersonMedicalMoney(BigDecimal personMedicalMoney) {
        this.personMedicalMoney = personMedicalMoney;
    }
    public BigDecimal getCompanyMedicalMoney() {
        return companyMedicalMoney;
    }

    public void setCompanyMedicalMoney(BigDecimal companyMedicalMoney) {
        this.companyMedicalMoney = companyMedicalMoney;
    }
    public BigDecimal getPersonUnemploymentMoney() {
        return personUnemploymentMoney;
    }

    public void setPersonUnemploymentMoney(BigDecimal personUnemploymentMoney) {
        this.personUnemploymentMoney = personUnemploymentMoney;
    }
    public BigDecimal getCompanyUnemploymentMoney() {
        return companyUnemploymentMoney;
    }

    public void setCompanyUnemploymentMoney(BigDecimal companyUnemploymentMoney) {
        this.companyUnemploymentMoney = companyUnemploymentMoney;
    }
    public BigDecimal getCompanyChildbirthMoney() {
        return companyChildbirthMoney;
    }

    public void setCompanyChildbirthMoney(BigDecimal companyChildbirthMoney) {
        this.companyChildbirthMoney = companyChildbirthMoney;
    }
    public BigDecimal getCompanyInjuryMoney() {
        return companyInjuryMoney;
    }

    public void setCompanyInjuryMoney(BigDecimal companyInjuryMoney) {
        this.companyInjuryMoney = companyInjuryMoney;
    }
    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }
    public String getDataState() {
        return dataState;
    }

    public void setDataState(String dataState) {
        this.dataState = dataState;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    
}

==> ejc-salary-api-3.0.0-20241210.045551-83-sources.jar: com/ejianc/business/salary/vo/RosterSocialSecurityVO.java <==
package com.ejianc.business.salary.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 人员花名册-社保
 * 
 * @author generator
 * 
 */
public class RosterSocialSecurityVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private BigDecimal paymentBase; // 缴费基数
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date startTime; // 社保执行时间
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date endTime; // 社保结束时间
    private BigDecimal personAnnuityMoney; // 个人养老金
    private BigDecimal companyAnnuityMoney; // 公司养老金
    private BigDecimal personMedicalMoney; // 个人医疗金额
    private BigDecimal companyMedicalMoney; // 公司医疗金额
    private BigDecimal personUnemploymentMoney; // 个人失业金额
    private BigDecimal companyUnemploymentMoney; // 公司失业金额
    private BigDecimal companyChildbirthMoney; // 公司生育金额
    private BigDecimal companyInjuryMoney; // 公司工伤金额
    private String changeReason; // 变更原因
    private String dataState; // 状态
    private String employeeCode; // 员工编码
    private String idCard; // 身份证号
    

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public BigDecimal getPaymentBase() {
        return paymentBase;
    }

    public void setPaymentBase(BigDecimal paymentBase) {
        this.paymentBase = paymentBase;
    }
    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
    public BigDecimal getPersonAnnuityMoney() {
        return personAnnuityMoney;
    }

    public void setPersonAnnuityMoney(BigDecimal personAnnuityMoney) {
        this.personAnnuityMoney = personAnnuityMoney;
    }
    public BigDecimal getCompanyAnnuityMoney() {
        return companyAnnuityMoney;
    }

    public void setCompanyAnnuityMoney(BigDecimal companyAnnuityMoney) {
        this.companyAnnuityMoney = companyAnnuityMoney;
    }
    public BigDecimal getPersonMedicalMoney() {
        return personMedicalMoney;
    }

    public void setPersonMedicalMoney(BigDecimal personMedicalMoney) {
        this.personMedicalMoney = personMedicalMoney;
    }
    public BigDecimal getCompanyMedicalMoney() {
        return companyMedicalMoney;
    }

    public void setCompanyMedicalMoney(BigDecimal companyMedicalMoney) {
        this.companyMedicalMoney = companyMedicalMoney;
    }
    public BigDecimal getPersonUnemploymentMoney() {
        return personUnemploymentMoney;
    }

    public void setPersonUnemploymentMoney(BigDecimal personUnemploymentMoney) {
        this.personUnemploymentMoney = personUnemploymentMoney;
    }
    public BigDecimal getCompanyUnemploymentMoney() {
        return companyUnemploymentMoney;
    }

    public void setCompanyUnemploymentMoney(BigDecimal companyUnemploymentMoney) {
        this.companyUnemploymentMoney = companyUnemploymentMoney;
    }
    public BigDecimal getCompanyChildbirthMoney() {
        return companyChildbirthMoney;
    }

    public void setCompanyChildbirthMoney(BigDecimal companyChildbirthMoney) {
        this.companyChildbirthMoney = companyChildbirthMoney;
    }
    public BigDecimal getCompanyInjuryMoney() {
        return companyInjuryMoney;
    }

    public void setCompanyInjuryMoney(BigDecimal companyInjuryMoney) {
        this.companyInjuryMoney = companyInjuryMoney;
    }
    public String getChangeReason() {
        return changeReason;
    }

    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }
    public String getDataState() {
        return dataState;
    }

    public void setDataState(String dataState) {
        this.dataState = dataState;
    }
    public String getEmployeeCode() {
        return employeeCode;
    }

    public void setEmployeeCode(String employeeCode) {
        this.employeeCode = employeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    
}
